.. These are examples of badges you might want to add to your README:
   please update the URLs accordingly

    .. image:: https://api.cirrus-ci.com/github/<USER>/pyElli.svg?branch=main
        :alt: Built Status
        :target: https://cirrus-ci.com/github/<USER>/pyElli
    .. image:: https://readthedocs.org/projects/pyElli/badge/?version=latest
        :alt: ReadTheDocs
        :target: https://pyElli.readthedocs.io/en/stable/
    .. image:: https://img.shields.io/coveralls/github/<USER>/pyElli/main.svg
        :alt: Coveralls
        :target: https://coveralls.io/r/<USER>/pyElli
    .. image:: https://img.shields.io/pypi/v/pyElli.svg
        :alt: PyPI-Server
        :target: https://pypi.org/project/pyElli/
    .. image:: https://img.shields.io/conda/vn/conda-forge/pyElli.svg
        :alt: Conda-Forge
        :target: https://anaconda.org/conda-forge/pyElli
    .. image:: https://pepy.tech/badge/pyElli/month
        :alt: Monthly Downloads
        :target: https://pepy.tech/project/pyElli
    .. image:: https://img.shields.io/twitter/url/http/shields.io.svg?style=social&label=Twitter
        :alt: Twitter
        :target: https://twitter.com/pyElli

.. image:: https://img.shields.io/badge/-PyScaffold-005CA0?logo=pyscaffold
    :alt: Project generated with PyScaffold
    :target: https://pyscaffold.org/

|

======
pyElli
======


    Python implementation of Berremans 4x4 matrix method


A longer description of your project goes here...


.. _pyscaffold-notes:

Note
====

This project has been set up using PyScaffold 4.1.1. For details and usage
information on PyScaffold see https://pyscaffold.org/.
